*****************
Task modules
*****************

.. automodule:: orion.benchmark.task
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Task modules of Oríon

   task/base
   task/branin
   task/carromtable
   task/eggholder
   task/rosenbrock
